﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace howto_highlight_current_datagridview_row
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // The style to use when the mouse is over a row.
        private DataGridViewCellStyle HighlightStyle;

        private void Form1_Load(object sender, EventArgs e)
        {
            // Define the highlight style.
            HighlightStyle = new DataGridViewCellStyle();
            HighlightStyle.ForeColor = Color.Red;
            HighlightStyle.BackColor = Color.Yellow;
            HighlightStyle.Font = new Font(dgvValues.Font, FontStyle.Bold);

            // Make some data items.
            dgvValues.Rows.Add(new object[] { "Interview Puzzles Dissected", 15.95m, 1 });
            dgvValues.Rows.Add(new object[] { "C# 24-Hour Trainer", 45.00m, 2 });
            dgvValues.Rows.Add(new object[] { "Beginning Software Engineering", 45.00m, 5 });
            dgvValues.Rows.Add(new object[] { "Essential Algorithms", 60.00m, 3 });
            dgvValues.Rows.Add(new object[] { "C# 5.0 Programmer's Reference", 49.99m, 1 });
            dgvValues.Rows.Add(new object[] { "Beginning Database Design Solutions", 44.99m, 2 });

            // Calculate totals.
            CalculateTotals();
        }

        // Calculate the total costs.
        private void CalculateTotals()
        {
            // Calculate the total costs.
            foreach (DataGridViewRow row in dgvValues.Rows)
            {
                // Calculate total cost.
                decimal total_cost =
                    (decimal)row.Cells["PriceEach"].Value *
                    (int)row.Cells["Quantity"].Value;

                // Display the value.
                row.Cells["Total"].Value = total_cost;
            }
        }

        // Set the cell Styles in the given row.
        private void SetRowStyle(DataGridViewRow row, DataGridViewCellStyle style)
        {
            foreach (DataGridViewCell cell in row.Cells)
            {
                cell.Style = style;
            }
        }

        // The currently highlighted cell.
        private int HighlightedRowIndex = -1;

        // Highlight this cell's row.
        private void dgvValues_CellMouseEnter(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex == HighlightedRowIndex) return;

            // Unhighlight the previously highlighted row.
            if (HighlightedRowIndex >= 0)
            {
                SetRowStyle(dgvValues.Rows[HighlightedRowIndex], null);
            }

            // Highlight the row holding the mouse.
            HighlightedRowIndex = e.RowIndex;
            if (HighlightedRowIndex >= 0)
            {
                SetRowStyle(dgvValues.Rows[HighlightedRowIndex], HighlightStyle);
            }
        }

        // Unhighlight the currently highlighted row.
        private void dgvValues_CellMouseLeave(object sender, DataGridViewCellEventArgs e)
        {
            if (HighlightedRowIndex >= 0)
            {
                SetRowStyle(dgvValues.Rows[HighlightedRowIndex], null);
                HighlightedRowIndex = -1;
            }
        }
    }
}
